pub enum WebsocketServiceMessageContent {
    OpenMessage(CanisterOpenMessageContent),
    AckMessage(CanisterAckMessageContent),
    KeepAliveMessage(ClientKeepAliveMessageContent),
    CloseMessage(CanisterCloseMessageContent),
}
A service message sent by the CDK to the client or vice versa.

Note: You should only use this struct in tests.

Variants



OpenMessage(CanisterOpenMessageContent)

Message sent by the canister when a client opens a connection.



AckMessage(CanisterAckMessageContent)

Message sent periodically by the canister to the client to acknowledge the messages received.



KeepAliveMessage(ClientKeepAliveMessageContent)

Message sent by the client in response to an acknowledgement message from the canister.



CloseMessage(CanisterCloseMessageContent)

Message sent by the canister when it wants to close the connection.

Implementations